@@ -115,6 +115,20 @@ class RandomPolicy(Policy):
         with io.open(json_file_path, 'w', encoding='utf-8') as f:
             f.write(json_str)
 
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "RandomPolicy":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return RandomPolicy.from_dict(json.loads(json_str))
+
     def copy(self) -> "RandomPolicy":
         """
         :return: a copy of the DTO
