@@ -61,19 +61,17 @@ class EnvDynamicsUtil:
         for n_m in new_machines_obs:
             if emulation_env_config.containers_config.agent_ip in n_m.ips:
                 continue
-            exists = False
             merged_m = n_m
             for i, o_m in enumerate(old_machines_obs):
-                if n_m.ips == o_m.ips:
+                if n_m.ips_match(o_m.ips):
                     merged_m = EnvDynamicsUtil.merge_new_machine_obs_with_old_machine_obs(o_m, n_m, action)
-                    exists = True
             attacker_machine_observations.append(merged_m)
 
         # Add old machines to merged state
         for o_m in old_machines_obs:
             exists = False
             for m_m in attacker_machine_observations:
-                if o_m.ips == m_m.ips:
+                if o_m.ips_match(m_m.ips):
                     exists = True
             if not exists:
                 attacker_machine_observations.append(o_m)
@@ -750,6 +748,12 @@ class EnvDynamicsUtil:
         """
         merged_machines = []
         ips: Set[str] = set()
+        for m in machines:
+            ip_suffixes = list(map(lambda x: x.split(".")[-1], m.ips))
+            for m1 in machines:
+                for ip in m1.ips:
+                    if ip.split(".")[-1] in ip_suffixes and ip not in m.ips:
+                        m.ips = list(set(m.ips + m1.ips))
         for m in machines:
             if not m.ips_match(list(ips)):
                 merged_m = m
@@ -757,5 +761,5 @@ class EnvDynamicsUtil:
                     if m2.ips == merged_m.ips:
                         merged_m = EnvDynamicsUtil.merge_new_machine_obs_with_old_machine_obs(merged_m, m2, action)
                 merged_machines.append(merged_m)
-                ips.union(set(m.ips))
+                ips = ips.union(set(m.ips))
         return merged_machines
